NDSubject class abstract

Available extensions

Constructors

NDSubject({NDCheckRelative? isRelative})

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setterinherited
isRelative NDCheckRelative
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(NDKeys keys, NDCallback callback) NDHandle

Available on NDSubject, provided by the NDSubjectUtils extension

didChange(NDKeys keys, [void action()?]) → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observe(NDKeys keys, NDCallback callback) NDHandle
removeObserver(NDHandle handle) → void
toString() String
A string representation of this object.
inherited
tunnel(NDKeys keys, NDSubject toSubject, {NDKeys? toKeys, NDDisposableBag? disposableBag, void action()?}) NDHandle

Available on NDSubject, provided by the NDSubjectUtils extension

Operators

operator ==(Object other) bool
The equality operator.
inherited